@@ -1,14 +1,13 @@
 /*
- * Copyright (C) 2013 Christian Babeux <christian.babeux@efficios.com>
+ * SPDX-FileCopyrightText: 2013 Christian Babeux <christian.babeux@efficios.com>
  *
  * SPDX-License-Identifier: GPL-2.0-only
  *
  */
 
-
 #include <signal.h>
 
-int main(int argc, char *argv[])
+int main(void)
 {
 	raise(SIGSEGV);
 	return 0;
